@@ -531,7 +531,7 @@ class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
         empty_form_as_p = str(self.empty_form.as_p())
         div_name = str(self.prefix) + 'div'
 
-        forms_as_p = super(BaseInlineFormSetWithAddMoreButton, self).as_p()
+        forms_as_p = super().as_p()
         p = f"""<div class="row" id="{div_name}">
         {forms_as_p}
         </div>
@@ -595,7 +595,7 @@ class DataTransform(forms.ModelForm):
                               'id': str(uuid.uuid4())}],
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
                 )
-                self.nested_data_transformer_form.extra = 0
+                self.nested_data_transformer_form.extra = self.instance.get_children().count()
 
 
         except Exception as e:
@@ -617,8 +617,7 @@ class DataTransform(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_constants_form.extra = 0
-        # self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
+        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count()
 
         hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         self.nested_hardware_outputs_form = HardwareTransformerForm(
@@ -638,7 +637,7 @@ class DataTransform(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_hardware_stats_form.extra = 0
+        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count()
 
     def as_p(self):
         print('wtf')
@@ -708,7 +707,8 @@ dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransf
                                                      fk_name='parent',
                                                      can_delete_extra=True,
                                                      form=DataTransform,
-                                                     formset=BaseInlineFormSetWithAddMoreButton
+                                                     formset=BaseInlineFormSetWithAddMoreButton,
+                                                     extra=0
                                                      )
 
 
@@ -739,7 +739,7 @@ class DataTransformRoot(forms.ModelForm):
                               'id': str(uuid.uuid4())}],
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset',
                 )
-                self.nested_data_transformer_form.extra = 0
+                self.nested_data_transformer_form.extra = self.instance.get_children().count()
 
             else:
 
@@ -762,7 +762,7 @@ class DataTransformRoot(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_constants_form.extra = 0
+        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count()
 
         hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         self.nested_hardware_outputs_form = HardwareTransformerForm(
@@ -782,7 +782,7 @@ class DataTransformRoot(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_hardware_stats_form.extra = 0
+        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count()
 
     def as_p(self):
         print('root')
